/*
 * gsampler-client-channel.h
 * Copyright (C) Lilian Monchalin 2011 <isaya07@users.sf.net>
 * 
 * gsampler is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * gsampler is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef _GSAMPLER_CLIENT_CHANNEL_H_
#define _GSAMPLER_CLIENT_CHANNEL_H_

#include "gsampler-client.h"

#define GSAMPLER_TYPE_CHANNEL_INFO (gsampler_channel_info_get_type ())
typedef struct _GsamplerChannelInfo GsamplerChannelInfo;
struct _GsamplerChannelInfo {
	gint id;
	gint audio;
	gint audio_channels;
	gchar* audio_routing;
	gint midi;
	gchar* file;
	gint instrument;
	gchar* inst_name;
	gint inst_status;
	gchar* engine;
	gdouble volume;
	gint midi_port;
	gchar* midi_chan;
	gchar* midi_map;
	gboolean mute;
	gboolean solo;
};

typedef struct _InstrumentInfo InstrumentInfo;
struct _InstrumentInfo {
	gchar* name;
	gchar* format;
	gchar* formatv;
	gchar* product;
	gchar* artists;
};

GType 					gsampler_channel_info_get_type (void) G_GNUC_CONST;
GsamplerChannelInfo* 	gsampler_channel_info_dup (const GsamplerChannelInfo* self);
void 					gsampler_channel_info_free (GsamplerChannelInfo* self);
void 					gsampler_channel_info_copy (const GsamplerChannelInfo* self, GsamplerChannelInfo* dest);
void 					gsampler_channel_info_destroy (GsamplerChannelInfo* self);

gint 					gsampler_client_create_channel (GsamplerClient* self);
gboolean 				gsampler_client_delete_channel (GsamplerClient* self, gint id);
gchar** 				gsampler_client_get_available_channel (GsamplerClient* self);
gchar** 				gsampler_client_get_available_engine_list (GsamplerClient* self);
GsamplerChannelInfo*	gsampler_client_get_channel_info (GsamplerClient* self, gint id);
gboolean 				gsampler_client_set_channel_volume (GsamplerClient* self, gint id, gdouble vol);
gboolean 				gsampler_client_set_channel_mute (GsamplerClient* self, gint id, gint state);
gboolean 				gsampler_client_set_channel_solo (GsamplerClient* self, gint id, gint state);
gboolean				gsampler_client_set_channel_midimap (GsamplerClient* self, gint id, gint map);
gboolean 				gsampler_client_set_channel_output (GsamplerClient* self, gint chan, gint audio);
gboolean				gsampler_client_set_channel_audio_output_channel (GsamplerClient* self, 
				                                                          gint chan, gint aud_out, gint aud_in);
gboolean 				gsampler_client_set_channel_input (GsamplerClient* self, gint chan, gint midi);
gboolean 				gsampler_client_load_instrument_modal (GsamplerClient* self, gint chan, const gchar* file, gint inst);
gboolean 				gsampler_client_load_instrument (GsamplerClient* self, gint chan, const gchar* file, gint inst);
gchar** 				gsampler_client_get_file_instrument_list (GsamplerClient* self, const gchar* file);
InstrumentInfo* 		gsampler_client_get_file_instrument_info (GsamplerClient* self, const gchar* file, gint id);
gboolean 				gsampler_client_load_engine (GsamplerClient* self, const gchar* engine, gint id);
gboolean 				gsampler_client_edit_channel_instrument (GsamplerClient* self, gint id);
gboolean 				gsampler_client_set_channel_midi_channel (GsamplerClient* self, gint id, const gchar* chan);
gboolean 				gsampler_client_set_channel_midi_port (GsamplerClient* self, gint id, gint port);
gboolean 				gsampler_client_send_channel_midi_note_on (GsamplerClient* self, gint id, gint pitch, gint vel);
gboolean 				gsampler_client_send_channel_midi_note_off (GsamplerClient* self, gint id, gint pitch, gint vel);

#endif /* _GSAMPLER_CLIENT_CHANNEL_H_ */