/*
 * gsampler-option.h
 * Copyright (C) Lilian Monchalin 2011 <isaya07@users.sf.net>
 * 
 * gsampler is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * gsampler is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef _GSAMPLER_OPTION_H_
#define _GSAMPLER_OPTION_H_

#include <gtk/gtk.h>

G_BEGIN_DECLS

#define GSAMPLER_TYPE_OPTION (gsampler_option_get_type ())
#define GSAMPLER_OPTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GSAMPLER_TYPE_OPTION, GsamplerOption))
#define GSAMPLER_OPTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GSAMPLER_TYPE_OPTION, GsamplerOptionClass))
#define GSAMPLER_IS_OPTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GSAMPLER_TYPE_OPTION))
#define GSAMPLER_IS_OPTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GSAMPLER_TYPE_OPTION))
#define GSAMPLER_OPTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GSAMPLER_TYPE_OPTION, GsamplerOptionClass))
#define GSAMPLER_OPTION_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GSAMPLER_TYPE_OPTION, GsamplerOptionPrivate))

typedef struct _GsamplerOption GsamplerOption;
typedef struct _GsamplerOptionClass GsamplerOptionClass;
typedef struct _GsamplerOptionPrivate GsamplerOptionPrivate;

struct _GsamplerOption {
	GObject parent_instance;
	GsamplerOptionPrivate * priv;
};

struct _GsamplerOptionClass {
	GObjectClass parent_class;
};

struct _GsamplerOptionPrivate {
	GKeyFile* key_file;
	gboolean first_start;
};

GType 			gsampler_option_get_type (void) G_GNUC_CONST;
GsamplerOption* gsampler_option_new (void);
GsamplerOption* gsampler_option_get_instance (void);

gint 			gsampler_option_get_integer (GsamplerOption* self, 
			                                 const gchar* group, const gchar* key);
gchar* 			gsampler_option_get_string (GsamplerOption* self, 
			                                const gchar* group, const gchar* key);
gboolean 		gsampler_option_get_boolean (GsamplerOption* self, 
		                                     const gchar* group, const gchar* key);
void 			gsampler_option_set_integer (GsamplerOption* self, 
			                                 const gchar* group, const gchar* key, gint val);
void 			gsampler_option_set_string (GsamplerOption* self, 
			                                const gchar* group, const gchar* key, const gchar* val);
void 			gsampler_option_set_boolean (GsamplerOption* self, 
			                                 const gchar* group, const gchar* key, gboolean val);
void 			gsampler_option_save_keyfile (GsamplerOption* self);
gboolean		gsampler_option_is_first_start (GsamplerOption* self);

G_END_DECLS

#endif /* _GSAMPLER_OPTION_H_ */